0.9.9 API documentation: vector_int3.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

vector_int3.hpp
Go to the documentation of this file.
1
4 #pragma once
5 #include "../detail/type_vec3.hpp"
6
7 namespace glm
8 {
11
15 typedef vec<3, int, defaultp> ivec3;
16
18 }//namespace glm
glm::ivec3
vec< 3, int, defaultp > ivec3
3 components vector of signed integer numbers.
Definition: vector_int3.hpp:15
glm
Definition: common.hpp:20